@@ -26,6 +26,7 @@ OC.L10N.register(
     "Update interval" : "Інтервал оновлення",
     "Use system cron for updates" : "Використовуйте системний cron для оновлень",
     "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
+    "Show all articles" : "Показати всі статті",
     "Move" : "Перемістити",
     "User Name" : "Ім'я користувача",
     "Share" : "Спільний доступ",
@@ -43,7 +44,6 @@ OC.L10N.register(
     "Documentation" : "Документація",
     "Keyboard shortcuts" : "Сполучення клавіш",
     "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
-    "Show all articles" : "Показати всі статті",
     "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
     "Rename" : "Перейменувати",
     "Delete" : "Вилучити",
@@ -54,8 +54,6 @@ OC.L10N.register(
     "Oldest first" : "Старіші спочатку",
     "Enable full text" : "Увімкнути контекстний",
     "Disable full text" : "Вимкнути контекстний",
-    "Previous" : "Назад",
-    "Next" : "Далі",
     "Toggle star article" : "Позначити статтю",
     "Mark unread" : "Позначити як не прочитане",
     "by" : "по",
